Serial

Struct Serial 

pub struct Serial<UART, PINS> { /* private fields */ }
Serial abstraction

Implementations

Source

impl<TX, RX> Serial<UART0, (TX, RX)>

pub fn uart0( uart: UART0, pins: (TX, RX), baud_rate: Bps<u32>, mcg: &MultipurposeClockGenerator<'_>, ) -> Self
where TX: TxPin<UART0>, RX: RxPin<UART0>,

Configures a UART peripheral to provide serial communication

pub fn split(self) -> (Tx<UART0>, Rx<UART0>)

Splits the Serial abstraction into a transmitter and a receiver half

pub fn free(self) -> (UART0, (TX, RX))

Releases the UART peripheral and associated pins

Source

impl<TX, RX> Serial<UART1, (TX, RX)>

pub fn uart1( uart: UART1, pins: (TX, RX), baud_rate: Bps<u32>, mcg: &MultipurposeClockGenerator<'_>, ) -> Self
where TX: TxPin<UART1>, RX: RxPin<UART1>,

Configures a UART peripheral to provide serial communication

pub fn split(self) -> (Tx<UART1>, Rx<UART1>)

Splits the Serial abstraction into a transmitter and a receiver half

pub fn free(self) -> (UART1, (TX, RX))

Releases the UART peripheral and associated pins

Source

impl<TX, RX> Serial<UART2, (TX, RX)>

pub fn uart2( uart: UART2, pins: (TX, RX), baud_rate: Bps<u32>, mcg: &MultipurposeClockGenerator<'_>, ) -> Self
where TX: TxPin<UART2>, RX: RxPin<UART2>,

Configures a UART peripheral to provide serial communication

pub fn split(self) -> (Tx<UART2>, Rx<UART2>)

Splits the Serial abstraction into a transmitter and a receiver half

pub fn free(self) -> (UART2, (TX, RX))

Releases the UART peripheral and associated pins